@@ -37,7 +37,38 @@
 #'           npackages = npackages,
 #'           itemnames = itemnames,
 #'           availability = availability)
-#'           
+#'
+#' @examplesIf interactive()           
+#' # run diagnostics to certify that randomization is balanced
+#' # the number of interactions should have the lower sd as possible
+#' # this verification may not work well when technologies are 
+#' # tested in different proportions
+#' design = randomize(ncomp = ncomp,
+#'                    npackages = npackages,
+#'                    itemnames = itemnames)
+#' 
+#' design$best = "A"
+#' 
+#' design$worst = "C"
+#' 
+#' # number of times each item is tested in the 
+#' # trial design
+#' ntest = table(unlist(design[,c(1:3)]))
+#' 
+#' ntest
+#' 
+#' # put into the PlackettLuce structure to check 
+#' # number of interactions between items 
+#' r = gosset::rank_tricot(design, c(1:3), c(4:5))
+#' 
+#' bn = gosset::set_binomialfreq(r)
+#' 
+#' bn$interactions = bn$win1 + bn$win2
+#' 
+#' bn = bn[,c(1,2,5)]
+#' 
+#' bn
+#' 
 #' @aliases randomise
 #' @importFrom Matrix Diagonal
 #' @importFrom methods as
@@ -503,13 +534,16 @@ makeAllocationsMatrix <- function(allocations){
   return(t(out))
 }
 
-# Rounding values to closest integer while retaining the same sum
-# From https://stackoverflow.com/questions/32544646/round-vector-of-numerics-to-integer-while-preserving-their-sum
+#' Rounding values to closest integer while retaining the same sum
+#' https://stackoverflow.com/questions/32544646/round-vector-of-numerics-to-integer-while-preserving-their-sum
+#' @examples 
+#' .smart.round(c(NA, 3.5, 7.8, 9, 10.4))
 #' @noRd
-.smart.round <- function(x) {
-  y <- floor(x)
-  indices <- utils::tail(order(x-y), round(sum(x)) - sum(y))
-  y[indices] <- y[indices] + 1
+.smart.round = function(x) {
+  x[is.na(x)] = 0
+  y = floor(x)
+  indices = utils::tail(order(x - y), round(sum(x)) - sum(y))
+  y[indices] = y[indices] + 1
   y
 }
 
